@@ -1,5 +1,7 @@
 #!/usr/bin/env python3
 
+from __future__ import annotations
+import typing
 import argparse
 
 import matplotlib.pyplot as mpl
@@ -15,7 +17,7 @@ lat, lon = np.meshgrid(np.arange(-90, 90, 0.1), np.arange(-180, 180, 0.2))
 x, y, z = pm.geodetic2ecef(lat, lon, args.alt_m)
 
 
-def panel(ax, val, name: str, cmap: str = None):
+def panel(ax, val, name: str, cmap: str | None = None):
     hi = ax.pcolormesh(lon, lat, val, cmap=cmap)
     ax.set_title(name)
     fg.colorbar(hi, ax=ax).set_label(name + " [m]")
@@ -23,7 +25,7 @@ def panel(ax, val, name: str, cmap: str = None):
 
 
 fg = mpl.figure(figsize=(16, 5))
-axs = fg.subplots(1, 3, sharey=True)
+axs: typing.Any = fg.subplots(1, 3, sharey=True)
 fg.suptitle("geodetic2ecef")
 
 panel(axs[0], x, "x", "bwr")
