@@ -1,4 +1,4 @@
-""" compute radii of auxiliary spheres"""
+"""compute radii of auxiliary spheres"""
 
 from __future__ import annotations
 
@@ -22,10 +22,8 @@ __all__ = [
     "biaxial",
 ]
 
-ELL = Ellipsoid.from_name("wgs84")
 
-
-def eqavol(ell: Ellipsoid = ELL) -> float:
+def eqavol(ell: Ellipsoid | None = None) -> float:
     """computes the radius of the sphere with equal volume as the ellipsoid
 
     Parameters
@@ -39,12 +37,15 @@ def eqavol(ell: Ellipsoid = ELL) -> float:
         radius of sphere
     """
 
+    if ell is None:
+        ell = Ellipsoid.from_name("wgs84")
+
     f = ell.flattening
 
     return ell.semimajor_axis * (1 - f / 3 - f**2 / 9)
 
 
-def authalic(ell: Ellipsoid = ELL) -> float:
+def authalic(ell: Ellipsoid | None = None) -> float:
     """computes the radius of the sphere with equal surface area as the ellipsoid
 
     Parameters
@@ -58,6 +59,9 @@ def authalic(ell: Ellipsoid = ELL) -> float:
         radius of sphere
     """
 
+    if ell is None:
+        ell = Ellipsoid.from_name("wgs84")
+
     e = ell.eccentricity
 
     if e > 0:
@@ -69,7 +73,7 @@ def authalic(ell: Ellipsoid = ELL) -> float:
         return ell.semimajor_axis
 
 
-def rectifying(ell: Ellipsoid = ELL) -> float:
+def rectifying(ell: Ellipsoid | None = None) -> float:
     """computes the radius of the sphere with equal meridional distances as the ellipsoid
 
     Parameters
@@ -83,6 +87,9 @@ def rectifying(ell: Ellipsoid = ELL) -> float:
         radius of sphere
     """
 
+    if ell is None:
+        ell = Ellipsoid.from_name("wgs84")
+
     return ((ell.semimajor_axis ** (3 / 2) + ell.semiminor_axis ** (3 / 2)) / 2) ** (2 / 3)
 
 
@@ -91,7 +98,7 @@ def euler(
     lon1,
     lat2,
     lon2,
-    ell: Ellipsoid = ELL,
+    ell: Ellipsoid | None = None,
     deg: bool = True,
 ):
     """computes the Euler radii of curvature at the midpoint of the
@@ -137,7 +144,7 @@ def euler(
     return rho * nu / den
 
 
-def curve(lat, ell: Ellipsoid = ELL, deg: bool = True, method: str = "mean"):
+def curve(lat, ell: Ellipsoid | None = None, deg: bool = True, method: str = "mean"):
     """computes the arithmetic average of the transverse and meridional
     radii of curvature at a specified latitude point
 
@@ -172,7 +179,7 @@ def curve(lat, ell: Ellipsoid = ELL, deg: bool = True, method: str = "mean"):
         raise ValueError("method must be mean or norm")
 
 
-def triaxial(ell: Ellipsoid = ELL, method: str = "mean") -> float:
+def triaxial(ell: Ellipsoid | None = None, method: str = "mean") -> float:
     """computes triaxial average of the semimajor and semiminor axes of the ellipsoid
 
     Parameters
@@ -188,6 +195,9 @@ def triaxial(ell: Ellipsoid = ELL, method: str = "mean") -> float:
         radius of sphere
     """
 
+    if ell is None:
+        ell = Ellipsoid.from_name("wgs84")
+
     if method == "mean":
         return (2 * ell.semimajor_axis + ell.semiminor_axis) / 3
     elif method == "norm":
@@ -196,7 +206,7 @@ def triaxial(ell: Ellipsoid = ELL, method: str = "mean") -> float:
         raise ValueError("method must be mean or norm")
 
 
-def biaxial(ell: Ellipsoid = ELL, method: str = "mean") -> float:
+def biaxial(ell: Ellipsoid | None = None, method: str = "mean") -> float:
     """computes biaxial average of the semimajor and semiminor axes of the ellipsoid
 
     Parameters
@@ -212,6 +222,9 @@ def biaxial(ell: Ellipsoid = ELL, method: str = "mean") -> float:
         radius of sphere
     """
 
+    if ell is None:
+        ell = Ellipsoid.from_name("wgs84")
+
     if method == "mean":
         return (ell.semimajor_axis + ell.semiminor_axis) / 2
     elif method == "norm":
