@@ -2,6 +2,8 @@ import functools
 from pathlib import Path
 from datetime import datetime
 
+import numpy as np
+
 import matlab.engine
 
 
@@ -16,13 +18,6 @@ def matlab_engine():
     return eng
 
 
-def pydt2matdt(eng, utc: datetime):
-    """
-    Python datetime.dateime to Matlab datetime
-    """
-    return eng.datetime(utc.year, utc.month, utc.day, utc.hour, utc.minute, utc.second)
-
-
 @functools.cache
 def has_matmap3d(eng) -> bool:
     cwd = Path(__file__).parent
@@ -38,9 +33,23 @@ def has_matmap3d(eng) -> bool:
 
 @functools.cache
 def has_aerospace(eng) -> bool:
-    return eng.matlab_toolbox()["aerospace"]
+    return eng.has_matlab_toolbox("Aerospace Toolbox")
 
 
 @functools.cache
 def has_mapping(eng) -> bool:
-    return eng.matlab_toolbox()["mapping"]
+    return eng.has_matlab_toolbox("Mapping Toolbox")
+
+
+def matlab_ecef2eci(eng, matmap3d: bool, utc: datetime, ecef):
+    if matmap3d:
+        return eng.matmap3d.ecef2eci(utc, *ecef, nargout=3)
+
+    return np.array(eng.ecef2eci(utc, np.asarray(ecef), nargout=1)).squeeze()
+
+
+def matlab_eci2ecef(eng, matmap3d: bool, utc: datetime, eci):
+    if matmap3d:
+        return eng.matmap3d.eci2ecef(utc, *eci, nargout=3)
+
+    return np.array(eng.eci2ecef(utc, np.asarray(eci), nargout=1)).squeeze()
