@@ -1,5 +1,4 @@
 import pymap3d as pm
-import pymap3d.rcurve as rcurve
 import pytest
 from pytest import approx
 
@@ -11,12 +10,12 @@ A = ell.semimajor_axis
     "lat,curvature", [(0, A), (90, 0), (-90, 0), (45.0, 4517590.87884893), (-45, 4517590.87884893)]
 )
 def test_rcurve_parallel(lat, curvature):
-    assert rcurve.parallel(lat) == approx(curvature, abs=1e-9, rel=1e-6)
+    assert pm.parallel(lat) == approx(curvature, abs=1e-9, rel=1e-6)
 
 
 def test_numpy_parallel():
     pytest.importorskip("numpy")
-    assert rcurve.parallel([0, 90]) == approx([A, 0], abs=1e-9, rel=1e-6)
+    assert pm.parallel([0, 90]) == approx([A, 0], abs=1e-9, rel=1e-6)
 
 
 @pytest.mark.parametrize(
@@ -30,14 +29,14 @@ def test_numpy_parallel():
     ],
 )
 def test_rcurve_meridian(lat, curvature):
-    assert rcurve.meridian(lat) == approx(curvature)
+    assert pm.meridian(lat) == approx(curvature)
 
 
 def test_numpy_meridian():
     pytest.importorskip("numpy")
-    assert rcurve.meridian([0, 90]) == approx([6335439.327, 6399593.6258])
+    assert pm.meridian([0, 90]) == approx([6335439.327, 6399593.6258])
 
 
 def test_numpy_transverse():
     pytest.importorskip("numpy")
-    assert rcurve.transverse([-90, 0, 90]) == approx([6399593.6258, A, 6399593.6258])
+    assert pm.transverse([-90, 0, 90]) == approx([6399593.6258, A, 6399593.6258])
